pub struct InstanceRegistry {
pub instances: Vec<Instance>,
pub active: Option<String>,
}Expand description
Instance registry stored at ~/.config/modde/instances.toml
Fields
instances: Vec<Instance>active: Option<String>Implementations
Sourceimpl InstanceRegistry
impl InstanceRegistry
Sourcepub fn active_data_dir(&self) -> Option<&Path>
pub fn active_data_dir(&self) -> Option<&Path>
Get the active instance’s data directory.
Sourcepub fn load_from(path: &Path) -> Self
pub fn load_from(path: &Path) -> Self
Load the registry from a specific file path (for testing).
Sourcepub fn save_to(&self, path: &Path) -> Result<()>
pub fn save_to(&self, path: &Path) -> Result<()>
Save the registry to a specific file path (for testing).