validate_profile_name

Function validate_profile_name 

pub fn validate_profile_name(name: &str) -> Result<()>
Validate that a profile name is safe for use as a filesystem directory and is not empty or excessively long.