pub struct ConflictMap {
pub files: HashMap<String, HashSet<ModId>>,
}Expand description
Maps each deployed file path to the set of mods that provide it.
Fields
files: HashMap<String, HashSet<ModId>>Implementations
Sourceimpl ConflictMap
impl ConflictMap
Sourcepub fn register(&mut self, file_path: String, mod_id: ModId)
pub fn register(&mut self, file_path: String, mod_id: ModId)
Register that mod_id provides file_path.
Sourcepub fn conflicts(&self) -> Vec<(&str, &HashSet<ModId>)>
pub fn conflicts(&self) -> Vec<(&str, &HashSet<ModId>)>
Return all file paths that have more than one provider.
Sourcepub fn winner_for(
&self,
file_path: &str,
priority_order: &[ModId],
hidden: &HashSet<(String, String)>,
) -> Option<ModId>
pub fn winner_for( &self, file_path: &str, priority_order: &[ModId], hidden: &HashSet<(String, String)>, ) -> Option<ModId>
Determine the winner for a given file path based on mod priority order.
priority_order lists mods from lowest to highest priority.
The last mod in the list that provides the file wins.
Hidden (mod_id, rel_path) pairs are excluded.